==> forestry_1.11.2-5.3.4.130-sources.jar: forestry/apiculture/network/packets/PacketImprintSelectionResponse.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.apiculture.network.packets;

import java.io.IOException;

import forestry.apiculture.gui.ContainerImprinter;
import forestry.core.network.ForestryPacket;
import forestry.core.network.IForestryPacketClient;
import forestry.core.network.IForestryPacketHandlerClient;
import forestry.core.network.PacketBufferForestry;
import forestry.core.network.PacketIdClient;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.Container;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

public class PacketImprintSelectionResponse extends ForestryPacket implements IForestryPacketClient {
	private final int primary;
	private final int secondary;

	public PacketImprintSelectionResponse(int primaryIndex, int secondaryIndex) {
		this.primary = primaryIndex;
		this.secondary = secondaryIndex;
	}

	@Override
	public PacketIdClient getPacketId() {
		return PacketIdClient.IMPRINT_SELECTION_RESPONSE;
	}

	@Override
	protected void writeData(PacketBufferForestry data) throws IOException {
		data.func_150787_b(primary);
		data.func_150787_b(secondary);
	}

	@SideOnly(Side.CLIENT)
	public static class Handler implements IForestryPacketHandlerClient {
		@Override
		public void onPacketData(PacketBufferForestry data, EntityPlayer player) throws IOException {
			Container container = player.field_71070_bA;
			if (container instanceof ContainerImprinter) {
				int primaryIndex = data.func_150792_a();
				int secondaryIndex = data.func_150792_a();

				((ContainerImprinter) container).setSelection(primaryIndex, secondaryIndex);
			}
		}
	}
}

==> forestry_1.12.2-5.8.0.309-sources.jar: forestry/apiculture/network/packets/PacketImprintSelectionResponse.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.apiculture.network.packets;

import java.io.IOException;

import forestry.apiculture.gui.ContainerImprinter;
import forestry.core.network.ForestryPacket;
import forestry.core.network.IForestryPacketClient;
import forestry.core.network.IForestryPacketHandlerClient;
import forestry.core.network.PacketBufferForestry;
import forestry.core.network.PacketIdClient;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.Container;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

public class PacketImprintSelectionResponse extends ForestryPacket implements IForestryPacketClient {
	private final int primary;
	private final int secondary;

	public PacketImprintSelectionResponse(int primaryIndex, int secondaryIndex) {
		this.primary = primaryIndex;
		this.secondary = secondaryIndex;
	}

	@Override
	public PacketIdClient getPacketId() {
		return PacketIdClient.IMPRINT_SELECTION_RESPONSE;
	}

	@Override
	protected void writeData(PacketBufferForestry data) {
		data.func_150787_b(primary);
		data.func_150787_b(secondary);
	}

	@SideOnly(Side.CLIENT)
	public static class Handler implements IForestryPacketHandlerClient {
		@Override
		public void onPacketData(PacketBufferForestry data, EntityPlayer player) {
			Container container = player.field_71070_bA;
			if (container instanceof ContainerImprinter) {
				int primaryIndex = data.func_150792_a();
				int secondaryIndex = data.func_150792_a();

				((ContainerImprinter) container).setSelection(primaryIndex, secondaryIndex);
			}
		}
	}
}
